<?php

namespace App;

use App\AvailabilityWall;
use App\Budget;
use App\Country;
use App\Polygon;
use App\User;
use App\Wall;
use Illuminate\Database\Eloquent\Model;

class Campaign extends Model
{
	const ADSERVER = 'adserver';
	const DSP = 'dsp';

	const ACTIVA = 'activa';
	const PAUSADA = 'pausada';
	const PROPUESTA = 'propuesta';
	const AUTORIZADA = 'autorizada';
	const FINALIZADA = 'finalizada';
	const CANCELADA = 'cancelada';

    const EDITABLE = 1;
    const NOT_EDITABLE = 0;

	protected $fillable = [
        'user_registry_id',
        'country_id',
        'name',
        'comentary',
        'investment',
        'status',
        'customer_campaign_id',
        'country',
        'editable'
    ];

    // Cast Data
    protected $casts = [
        'editable'  =>  'string'
    ];

    /* Mutadores, cambiaran el valor antes de insertar valores */
    public function setNameAttribute($name) {
        $this->attributes['name'] = mb_strtolower($name);
    }

    public function setComentaryAttribute($comentary) {
        $this->attributes['comentary'] = mb_strtolower($comentary);
    }

    public function setTypeOfCampaignAttribute($type_of_campaign) {
        $this->attributes['type_of_campaign'] = mb_strtolower($type_of_campaign);
    }

    public function setStatusAttribute($status) {
        $this->attributes['status'] = mb_strtolower($status);
    }

    public function setCountryAttribute($country) {
        $this->attributes['country'] = mb_strtolower($country);
    }
    /* Mutadores, cambiaran el valor antes de insertar valores */

    public function walls() {
        return $this->belongsToMany(Wall::class, 'campaign_walls')->withPivot('flag');
    }

    public function witnesses() {
        return $this->hasMany(CampaignWitness::class);
    }

    public function availabilityWalls() {
        return $this->belongsToMany(AvailabilityWall::class, 'availability_walls', 'wall_id');
    }

    public function seller() {
        return $this->belongsTo(User::class, 'user_registry_id');
    }

    public function country() {
        return $this->belongsTo(Country::class);
    }

    public function customer() {
        return $this->belongsTo(User::class, 'customer_campaign_id');
    }

    public function polygons() {
        return $this->hasMany(Polygon::class);
    }

    public function pointsOfInterest() {
        return $this->hasMany(PointOfInterest::class);
    }

    public function mappingFiles() {
        return $this->belongsToMany(MappingFile::class, 'campaign_mapings_files');
    }

    public function budget() {
        return $this->hasOne(Budget::class);
    }

}
