<?php

namespace App;

use App\Campaign;
use App\Company;
use App\PublicTransport;
use App\State;
use App\Team;
use App\User;
use App\Wall;
use Illuminate\Database\Eloquent\Model;

class Country extends Model
{
     protected $fillable = [
        'country_name',
        'dollar_change',
        'tax',
        'type_of_currency'
    ];

    // Cast Data
    protected $casts = [
        'latitdollar_changeude'        =>  'double',
        'tax'       =>  'double'
    ];

    protected $hidden = ['pivot'];

    /* Mutadores, cambiaran el valor antes de insertar valores */
    public function setCountryNameAttribute($country_name) {
        $this->attributes['country_name'] = mb_strtolower($country_name);
    }

    public function setTypeOfCurrencyAttribute($type_of_currency) {
        $this->attributes['type_of_currency'] = mb_strtolower($type_of_currency);
    }

    public function companies() {
        return $this->hasMany(Company::class);
    }

    public function users() {
        return $this->hasMany(User::class);
    }

    public function screens() {
        return $this->hasMany(Wall::class);
    }

    public function public_transports() {
        return $this->hasMany(PublicTransport::class);
    }

    public function campaigns() {
        return $this->hasMany(Campaign::class);
    }

    public function teams() {
        return $this->belongsToMany(Team::class, 'country_team');
    }

    public function states() {
        return $this->hasMany(State::class, 'country_id');
    }
}
