<?php

namespace App\Http\Controllers\Budget;

use App\Budget;
use App\Campaign;
use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class BudgetController extends ApiController
{
    public function __construct()
    {
        parent::__construct();
        $this->middleware( 'can:budget.store' )->only( 'store' );
        $this->middleware( 'can:budget.show' )->only( 'show' );
    }

    /**
     * Gauradar un presupuesto
        Roles
        ** Superadministrator
        ** Administrador
        ** Salesmanager
        ** Sellercosts
        ** Customercosts
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Campaign $campaign)
    {
        if ( $campaign->editable == Campaign::NOT_EDITABLE ) {
            if ( !auth()->user()->hasRole( 'superadministrator' ) && !auth()->user()->hasRole( 'administrator' ) ) {
                return $this->errorResponse('Non-editable resource', 409);
            }
        }

        if ( !auth()->user()->hasRole( 'superadministrator' ) && !auth()->user()->hasRole( 'administrator' ) ) {

            if ( auth()->user()->hasRole( 'salesmanager' ) ) {

                if ( auth()->user()->id != $campaign->user_registry_id ) {

                    if ( $campaign->seller->admin_registry_id != auth()->user()->id ) {
                        return $this->errorResponse('Error, you do not have access to this resource', 403);
                    }

                }

            } else {
                if (auth()->user()->id != $campaign->user_registry_id) {
                    return $this->errorResponse('Error, you do not have access to this resource', 403);
                }
            }

        }

        $rules = [
            'campaign_id' => ['required', 'integer'],
            'data_json' => ['required'],
            'flag' => ['required', 'numeric'],
            'discount' => ['numeric']
        ];

        $this->validate(request(), $rules);

        Budget::where('campaign_id', $campaign->id)->delete();

        $budget = Budget::create(request()->all());

        return $this->showOne($budget, 201);
    }

    /**
     * Obtener un presupuesto
         Roles
            ** Superadministrator
            ** Administrador
            ** Salesmanager
            ** Sellercosts
            ** Customercosts
     *
     * @param  \App\Budget  $budget
     * @return \Illuminate\Http\Response
     */
    public function show(Campaign $campaign)
    {
        return $this->showOne($campaign->budget);
    }
}
