<?php

namespace App\Http\Controllers\Campaign;

use App\Campaign;
use App\Company;
use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Database\Eloquent\Collection;

class CampaignPucharseOrderController extends ApiController
{
    public function __construct()
    {
        parent::__construct();
        $this->middleware('can:campaign.pucharse.order.index')->only('index');
        $this->middleware('can:campaign.pucharse.order.exportPDF')->only('exportPDF');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Campaign $campaign)
    {
        $providers = [];
        foreach ($campaign->walls as $key => $wall) {
            if (!array_key_exists($wall->company->name_company, $providers)) {
                $providers[$wall->company->name_company]['number_walls'] = 1;
                $providers[$wall->company->name_company]['company_id'] = $wall->company->id;
            } else {
                $providers[$wall->company->name_company]['number_walls'] += 1;
            }
        }

        $providers['budget'] = $campaign->budget ? true : false;

        return $this->showAll(Collection::make($providers));
    }

    /**
     *
     */
    public function exportPDF(Campaign $campaign, Company $company)
    {
        $walls_campaign = $campaign->walls()->where( 'company_id', $company->id )
            ->with('country')->get();

        $countryCampaign = $campaign->country()->first();

        $budget = $campaign->budget;
        $budgetDataJson = json_decode($budget->data_json, true);

        $time = 0;

        $wall_data = [];
        foreach ($budgetDataJson as $key => $budget) {
            $wall_data[$budget['wall_id']] = $budget['time'];
        }

        $tbody = '';
        $priceTotal = 0;
        $priceTotalUSD = 0;

        $timeData = [
            1 => 'Semanas',
            2 => 'Quincenas',
            4 => 'Meses'
        ];

        $thead = '<tr>
                        <th>PLATAFORMA</th>
                        <th>MURO</th>
                        <th>SEGMENTACIÓN</th>
                        <th>NO. DE MUROS</th>
                        <th>TIEMPO</th>
                        <th>MONTO DE INVERSIÓN</th>
                 </tr>';

        foreach ($walls_campaign as $key => $wall) {

            $number_walls = empty($wall->number_faces) ? 1 : $wall->number_faces;

            $tbody .= '
                        <tr>
                            <td>DOOH</td>
                            <td>'.$wall->provider_wall_id.'</td>
                            <td>'.$wall->country->country_name.'</td>
                            <td>'.$number_walls.'</td>
                            <td>'.number_format($wall_data[$wall->id]).' '. $timeData[ $wall->sales_model ] .'</td>
                            <td>'.number_format($wall_data[$wall->id] * $wall->local_currency, 2).'
                                <br>
                                <small>'. mb_strtoupper( $wall->country->type_of_currency ).'</small>
                            </td>
                        </tr>
                    ';

            $priceUSD = $wall->local_currency / $wall->country->dollar_change;
            $priceTotal += ($priceUSD * $countryCampaign->dollar_change  * $wall_data[$wall->id]);
        }


        $html = '
                <!DOCTYPE HTML>
                <html lang="es">
                    <head>
                        <style type="text/css">
                        .nav {
                            width:100%;
                            background:#212020;
                        }
                        .logo {
                            padding:8px;
                            margin-right: 10px;
                            padding-top: 20px;
                        }

                        #customers {
                          font-family: Arial, Helvetica, sans-serif;
                          border-collapse: collapse;
                          width: 100%;
                        }

                        #customers td, #customers th {
                          border: 1px solid #ddd;
                          padding: 8px;
                        }

                        #customers tr:nth-child(even){background-color: #f2f2f2;}

                        #customers tr:hover {background-color: #ddd;}

                        #customers th {
                          padding-top: 12px;
                          padding-bottom: 12px;
                          text-align: left;
                          background-color: #4CAF50;
                          color: white;
                        }

                        .info-campana {
                            margin-top: 5px;
                        }

                        .nombre-campana {
                            color:white;
                            margin-left:40%;
                            font-size:20px;
                            font-weight: bold;
                        }

                        .table-orden-compra {
                            width:100%;
                            font-size:10px;
                        }

                        .tbody-orden-compra {
                            font-size: 12px;
                        }

                        .border-cero {
                            border:0px solid white;
                            background: white;
                        }

                        .border-cero-derecha {
                            border-top:0px;
                            border-left:0px;
                            border-bottom:0px;
                        }
                        </style>
                    </head>
                    <body>
                        <div class="nav">
                            <div class="logo">
                                <img src="http://prodooh.com/ooh/images/logo/prodooh.png">
                                <span class="nombre-campana">
                                    '.ucwords($campaign->name).' - '.ucwords($company->name_company).'
                                </span>
                            </div>
                        </div>
                        <div class="info-campana">
                            <p> Detalles campaña </p>
                            <ul>
                                <li>
                                    Campaña: '.ucwords($campaign->name).'
                                </li>
                                <li>
                                    Campaña ID: '.$campaign->id.'
                                </li>
                                <li>
                                    País: '.$countryCampaign->country_name.'
                                </li>
                            </ul>
                        </div>
                        <div class="table-orden-compra">
                            <table id="customers">
                                <thead>'. $thead .'</thead>

                                <tbody class="tbody-orden-compra">
                                '.$tbody.'
                                </tbody>
                                <tfoot style="font-size: 15px;">
                                    <tr>
                                        <th>Totales</th>
                                        <th></th>
                                        <th></th>
                                        <th></th>
                                        <th>$ '. number_format( $priceTotal / $countryCampaign->dollar_change ) .' USD</th>
                                        <th>$ '. number_format( $priceTotal ) .' '. $countryCampaign->type_of_currency .'</th>
                                    </tr>
                                </tfoot>

                            </table>

                        </div>
                    </body>
                </html>

            ';

        $pdf = \PDF::loadHTML($html)->setPaper('a4', 'landscape')->setWarnings(false);

        $name = $campaign->id.' - '.$company->name_company.'.pdf';

        $pdf->save( public_path().'/pdfs/temporary/'.$name );

        return $this->showMessage($name, 200);
    }
}
