<?php

namespace App\Http\Controllers\MappingFile;

use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use App\MappingFile;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Validator;

class MappingFileController extends ApiController
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $mappings_files;
        if (auth()->user()->hasRole('superadministrator') || auth()->user()->hasRole('administrator')) {
            $mappings_files = MappingFile::all();
        } else {
            $mappings_files = MappingFile::where('user_id', auth()->user()->id)
                                            ->get();
        }
        return $this->showAll(Collection::make($mappings_files));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store()
    {
        $rules = [
            'name'          =>   ['required', 'string'],
            'description'   =>   ['string'],
            'file'          =>   ['required', 'string']
        ];

        $this->validate(request(), $rules);

        $fields = request()->all();

        $fields['user_id'] = auth()->user()->id;
        
        $mapping_file = MappingFile::create($fields);

        return $this->showOne(Collection::make($mapping_file));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\MappingFile  $mappingFile
     * @return \Illuminate\Http\Response
     */
    public function update(MappingFile $mappingFile)
    {
        if (!auth()->user()->hasRole('superadministrator') && !auth()->user()->hasRole('administrator')) {
            if ($mappingFile->user_id !== auth()->user()->id) {
                return $this->errorResponse('Error, you do not have access to this resource', 403);
            }
        }
        $rules = [
            'name'          =>   ['string'],
            'description'   =>   ['string'],
            'file'          =>   ['string']
        ];

        $this->validate(request(), $rules);

        $mappingFile->fill(request()->only([
            'name',
            'description',
            'file',
        ]));

        $mappingFile->save();

        return $this->showOne($mappingFile);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\MappingFile  $mappingFile
     * @return \Illuminate\Http\Response
     */
    public function destroy(MappingFile $mappingFile)
    {
        if (!auth()->user()->hasRole('superadministrator') && !auth()->user()->hasRole('administrator')) {
            if ($mappingFile->user_id !== auth()->user()->id) {
                return $this->errorResponse('Error, you do not have access to this resource', 403);
            }
        }
        Storage::disk('kml_kmz_files')->delete( $mappingFile->file );
        $mappingFile->delete();
        return $this->showOne($mappingFile, 200);
    }

    /**
     * Subir archivo del usuario
        ROLE
        ** TODOS LOS ROLES
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function uploadFile() {

        $file = request()->file( 'file' );

        // return $file->getClientOriginalName();

        $input = array( 'file' => $file );
        $rules = [ 'file' => ['required'] ];

        $validate = Validator::make($input, $rules);

        if ($validate->fails())
        {
            return $this->errorResponse('Only kml or kmz', 422);
        }

        $name = time().'.'.request()->file('file')->getClientOriginalExtension();

        Storage::disk('kml_kmz_files')->put($name, File::get($file));
        $data['file'] = $name;

        return $this->responseUploadFile( $data, 201 );
    }

    /**
     * Eliminar imagen
        ROLE
        ** TODOS LOS ROLES
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function deleteFile() {
        $rules = [
            'file'        =>    ['required', 'string']
        ];

        $this->validate( request(), $rules );

        Storage::disk('kml_kmz_files')->delete( request( 'file' ) );

        return $this->showMessage('Deleted File', 200);
    }
}
