<?php

namespace App\Http\Controllers\PublicTransport;

use App\Company;
use App\Country;
use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use App\PublicTransport;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Http\Request;

class PublicTransportController extends ApiController
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $transports = PublicTransport::orderBy( 'id', 'desc' )
                     ->with('company:id,name_company')
                     ->with( 'country:id,country_name' )
                     ->paginate( 8 );
                     // ->makeHidden('local_currency');
        return $this->showAll( Collection::make($transports) );
    }

    /**
     * Listar pantallas filtradas
        ROLES
        ** Todos los roles, menos el suspendido
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function filteredPublicTransports()
    {

        $rules = [
                    'countries_ids.*' => ['numeric'],
                    'states.*' => ['string']
                ];

        $this->validate(request(), $rules);

        $public_transports;

        if (!request('states')) {
            // With company es necesario para filtro administrador de empresas
            if (auth()->user()->hasRole('superadministrator') || auth()->user()->hasRole('administrator')) {

                if (request('countries_ids')) {
                    $public_transports = PublicTransport::where(
                                                [
                                                    ['disabled', '=', false],
                                                ]
                                            )
                                            ->whereIn('country_id', request('countries_ids'))
                                            ->with( 'company:id,name_company' )
                                            ->with( 'country:id,country_name' )
                                            ->get()
                                            ->makeHidden('local_currency');
                }

                if (!request('countries_ids')) {

                  if (count(auth()->user()->company->countries) > 0) {
                    $countriesIDs = auth()->user()->company->countries->map(function ($country) {
                        return strval($country->id);
                    });

                    $public_transports = PublicTransport::where(
                                      [
                                          ['disabled', '=', false]
                                      ]
                                   )
                                   ->whereIn( 'country_id', $countriesIDs)
                                   ->with( 'company:id,name_company' )
                                   ->with( 'country:id,country_name' )
                                   ->get()
                                   ->makeHidden('local_currency');
                  } else {
                    $public_transports = PublicTransport::where(
                                          [
                                              ['disabled', '=', false]
                                          ]
                                       )
                                       ->with( 'company:id,name_company' )
                                       ->with( 'country:id,country_name' )
                                       ->get()
                                       ->makeHidden('local_currency');   
                  }
                }

                return $this->showAll( Collection::make($public_transports) );
            }

            if ( auth()->user()->hasRole('administratorprovider') ) {


                if (request('countries_ids')) {
                    $public_transports = PublicTransport::where(
                                        [
                                            ['company_id', '=', auth()->user()->company_id]
                                        ]
                                     )
                                     ->whereIn('country_id', request('countries_ids'))
                                     ->with( 'country:id,country_name' )
                                     ->get()
                                     ->makeHidden('local_currency');
                }

                // Revisar este metodo
                if (!request('countries_ids')) {
                    $public_transports = auth()->user()
                                     ->company
                                     ->public_transports
                                     ->with( 'country:id,country_name' )
                                     ->makeHidden('local_currency');
                }

                return $this->showAll( Collection::make($public_transports) );
            }


            if (request('countries_ids')) {
                $public_transports = PublicTransport::where(
                                            [
                                                ['disabled', '=', false]
                                            ]
                                        )
                                        ->whereIn('country_id', request('countries_ids'))
                                        ->with( 'country:id,country_name' )
                                        ->get()
                                        ->makeHidden('local_currency');
            }

            if (!request('countries_ids')) {

                if (count(auth()->user()->company->countries) > 0) {
                    $countriesIDs = auth()->user()->company->countries->map(function ($country) {
                        return strval($country->id);
                    });

                    $public_transports = PublicTransport::where(
                                      [
                                          ['disabled', '=', false]
                                      ]
                                   )
                                   ->whereIn( 'country_id', $countriesIDs)
                                   ->with( 'country:id,country_name' )
                                   ->get()
                                   ->makeHidden('local_currency');
                  } else {
                    $public_transports = PublicTransport::where(
                                          [
                                              ['disabled', '=', false]
                                          ]
                                       )
                                       ->with( 'country:id,country_name' )
                                       ->get()
                                       ->makeHidden('local_currency');   
                  }
            }
        } else {
            /*
                Entrara cuando tenga ciudades y estados seleccionados
                Esta opcion es la unica manera para mostrar brazil
            */
            if (auth()->user()->hasRole('superadministrator') || auth()->user()->hasRole('administrator')) {
                $public_transports = PublicTransport::where(
                                            [
                                                'disabled' => false
                                            ]
                                        )
                                        ->whereIn('country_id', request('countries_ids'))
                                        ->whereIn('state', request('states'))
                                        ->with( 'company:id,name_company' )
                                        ->with( 'country:id,country_name' )
                                        ->get()
                                        ->makeHidden('local_currency');
                return $this->showAll( Collection::make($public_transports) );
            }

            if ( auth()->user()->hasRole('administratorprovider') ) {
                $public_transports = PublicTransport::where(
                                        [
                                            'company_id' => auth()->user()->company_id,
                                        ]
                                    )
                                     ->whereIn('country_id', request('countries_ids'))
                                     ->whereIn('state', request('states'))
                                     ->with( 'country:id,country_name' )
                                     ->get()
                                     ->makeHidden('local_currency');

                return $this->showAll( Collection::make($public_transports) );
            }

            if (request('countries_ids')) {
                $public_transports = PublicTransport::where(
                                            [
                                                'disabled' => false
                                            ]
                                        )
                                        ->whereIn('country_id', request('countries_ids'))
                                        ->whereIn('state', request('states'))
                                        ->with( 'country:id,country_name' )
                                        ->get()
                                        ->makeHidden('local_currency');
            }

        }

        return $this->showAll( Collection::make($public_transports) );
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store()
    {
        $rules = [
            'provider_transport_id'     =>      ['required', 'string'],
            'company_id'                =>      ['required', 'integer'],
            'country_id'                =>      ['required', 'integer'],
            'type'                      =>      ['required', 'string'],
            'type_of_vehicle'           =>      ['required', 'string'],
            'state'                     =>      ['required', 'string'],
            'town_hall_delegation'      =>      ['string'],
            'suburb'                    =>      ['string'],
            'street'                    =>      ['string'],
            'location_number'           =>      ['string'],
            'postal_code'               =>      ['string'],
            'measure_in_pixels'         =>      ['string'],
            'measure_in_meters'         =>      ['string'],
            'photographic_witness'      =>      ['boolean'],
            'witness_time'              =>      ['integer'],
            'spot_time_seconds'         =>      ['integer'],
            'local_currency'            =>      ['numeric'],
            'description'               =>      ['string'],
            'purchase_remarks'          =>      ['string'],
            'url_img'                   =>      ['string'],
            'number_of_units'           =>      ['integer'],
            'minimum_number_units_contract' =>  ['integer'],
            'number_screens'            =>      ['integer'],
            'screens_per_vehicle'       =>      ['integer'],
            'supports_image'            =>      ['required', 'boolean'],
            'supports_video'            =>      ['required', 'boolean'],
            'supports_image_gif'        =>      ['required', 'boolean'],
            'minimun_days'              =>      ['integer'],
            'minimun_spots'             =>      ['integer'],
            'tags'                      =>      ['string'],
            'black_list'                =>      ['string'],
            'modality'                  =>      ['string'],
            'capacity'                  =>      ['integer'],
            'total_people_per_month'    =>      ['integer'],
            'contained'                 =>      ['boolean'],
            'in_or_out'                 =>      ['string'],
            'public_or_app'             =>      ['string'],
            'route'                     =>      ['string'],
            'programmatic_traditional'  =>      ['required', 'in:programmatic,traditional'],
            'points'                    =>      ['required']
        ];

        $this->validate(request(), $rules);

        $company = Company::find(request('company_id'));

        if (!$company) {
            return $this->errorResponse('Non-existent company', 404);
        } else {
            if ($company->role != 'provider') {
                return $this->errorResponse('The company is not a type of supplier', 404);
            }
        }

        if (!Country::find(request('country_id'))) {
            return $this->errorResponse('Non-existent country', 404);
        }

        $fields = request()->all();
        $fields['points'] = json_encode($fields['points']);

        $transport_public = PublicTransport::create($fields);

        return $this->showOne($transport_public, 201);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\PublicTransport  $publicTransport
     * @return \Illuminate\Http\Response
     */
    public function show(PublicTransport $publicTransport)
    {
        if (auth()->user()->hasRole('administratorprovider')) {
            if (auth()->user()->company_id != $screen->company_id) {
                return $this->errorResponse('Error, you do not have access to this resource', 422);
            }
            $publicTransport = $publicTransport->makeHidden('local_currency')->load('country');
            return $this->showOne($publicTransport);
        }


        if (auth()->user()->hasRole('salesmanager') || auth()->user()->hasRole('sellercosts') || auth()->user()->hasRole('customercosts')) {
            $publicTransport = $publicTransport->load('country');
            return $this->showOne($publicTransport);
        } elseif (auth()->user()->hasRole('superadministrator') || auth()->user()->hasRole('administrator')) {
            $publicTransport = $publicTransport->load('country')->load('company');
            return $this->showOne($publicTransport);
        } else {
            return $this->showOne($publicTransport->makeHidden('local_currency')->load('country'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\PublicTransport  $publicTransport
     * @return \Illuminate\Http\Response
     */
    public function update(PublicTransport $publicTransport)
    {
        if (!auth()->user()->hasRole('superadministrator')) {
            if (!$this->validateTeamPermissions($screen->country_id)) {
                return $this->errorResponse('Error, you do not have access to this resource', 403);
            }
        }

        $rules = [
            'provider_transport_id'     =>      ['string'],
            'company_id'    =>      ['integer'],
            'country_id'    =>      ['integer'],
            'type'          =>      ['string'],
            'type_of_vehicle' =>    ['string'],
            'state'         =>      ['string'],
            'town_hall_delegation' => ['string'],
            'suburb'        =>      ['string'],
            'street'        =>      ['string'],
            'location_number' =>    ['string'],
            'postal_code'   =>      ['string'],
            'measure_in_pixels' =>  ['string'],
            'measure_in_meters' =>  ['string'],
            'photographic_witness' => ['boolean'],
            'witness_time'      =>  ['integer'],
            'spot_time_seconds' =>  ['integer'],
            'local_currency'    =>  ['numeric'],
            'description'   =>      ['string'],
            'purchase_remarks'  =>  ['string'],
            'url_img'        =>     ['string'],
            'number_of_units' =>    ['integer'],
            'minimum_number_units_contract' =>    ['integer'],
            'number_screens' =>     ['integer'],
            'screens_per_vehicle'       =>      ['integer'],
            'supports_image' =>     ['boolean'],
            'supports_video' =>     ['boolean'],
            'supports_image_gif' => ['boolean'],
            'minimun_days'   =>     ['integer'],
            'minimun_spots'  =>     ['integer'],
            'tags'           =>     ['string'],
            'black_list'     =>     ['string'],
            'modality'       =>     ['string'],
            'capacity'       =>     ['integer'],
            'total_people_per_month' => ['integer'],
            'contained'      =>     ['boolean'],
            'in_or_out'      =>     ['string'],
            'public_or_app'  =>     ['string'],
            'programmatic_traditional'  =>      ['in:programmatic,traditional'],
            'route'          =>     ['string']
        ];

        $this->validate(request(), $rules);

        $publicTransport->fill(request()->only(
            'provider_transport_id',
            'company_id',
            'country_id',
            'type',
            'type_of_vehicle',
            'state',
            'town_hall_delegation',
            'suburb',
            'street',
            'location_number',
            'postal_code',
            'measure_in_pixels',
            'measure_in_meters',
            'photographic_witness',
            'witness_time',
            'spot_time_seconds',
            'local_currency',
            'description',
            'purchase_remarks',
            'url_img',
            'number_of_units',
            'minimum_number_units_contract',
            'number_screens',
            'screens_per_vehicle',
            'supports_image',
            'supports_video',
            'supports_image_gif',
            'minimun_days',
            'minimun_spots',
            'tags',
            'black_list',
            'modality',
            'capacity',
            'total_people_per_month',
            'contained',
            'in_or_out',
            'public_or_app',
            'route',
            'programmatic_traditional',
            'points'
        ));

        if (request('company_id')) {
            $company = Company::find(request('company_id'));
            if (!$company) {
                return $this->errorResponse('Non-existent company', 404);
            } else {
                if ($company->role != 'provider') {
                    return $this->errorResponse('The company is not a type of supplier', 404);
                }
            }
            $publicTransport->company_id = request('company_id');
        }

        if (request('country_id')) {
            if (!Country::find(request('country_id'))) {
                return $this->errorResponse('Non-existent country', 404);
            }
            $publicTransport->country_id = request('country_id');
        }

        $publicTransport->save();

        return $this->showOne($publicTransport);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\PublicTransport  $publicTransport
     * @return \Illuminate\Http\Response
     */
    public function destroy(PublicTransport $publicTransport)
    {
        if (!auth()->user()->hasRole('superadministrator')) {
            if (!$this->validateTeamPermissions($screen->country_id)) {
                return $this->errorResponse('Error, you do not have access to this resource', 403);
            }
        }
        $publicTransport->campaigns()->detach();
        $publicTransport->delete();
        return $this->showOne($publicTransport);
    }

    /**
     * Subir imagen del usuario
        -- Sube la imagen, pero se guardara en el momento que se cree o actualize un usuario
        ROLE
        ** TODOS LOS ROLES
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function uploadImage(Company $company) {
        $img = request()->file( 'file' );

        $input = [
            'image' => $img
        ];

        $rules = [ 
            'image' => ['required', 'image']
        ];

        $validate = Validator::make($input, $rules);

        if ($validate->fails())
        {
            return $validate->errors();
        }

        if ($company->role != 'provider') {
            return $this->errorResponse('The company is not a type of supplier', 404);
        }

        $data['image'] = request('file')->store('/'.$company->id, 'img_screens');

        return $this->responseUploadFile( $data, 201 );
    }

    /**
     * Eliminar imagen
        ROLE
        ** TODOS LOS ROLES
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function deleteImage() {
        $rules = [
            'img'        =>    ['required', 'string']
        ];

        $this->validate( request(), $rules );

        Storage::disk('img_screens')->delete( request( 'img' ) );

        return $this->showMessage('Deleted Image', 200);
    }

    /**
     * Eliminar imagen del usuario
        ROLE
        ** TODOS LOS ROLES
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function deleteScreenImage(PublicTransport $publicTransport) {
        Storage::disk('img_screens')->delete( request( $publicTransport->url_img ) );
        $publicTransport->url_img = null;
        $publicTransport->save();
        return $this->showOne( $publicTransport );
    }
}
