<?php

namespace App\Http\Controllers\Team;

use App\Country;
use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use App\Team;
use App\User;
use Illuminate\Http\Request;

class TeamController extends ApiController
{
    public function __construct()
    {
        parent::__construct();
        $this->middleware( 'can:teams.index' )->only( 'index' );
        $this->middleware( 'can:teams.store' )->only( 'store' );
        $this->middleware( 'can:teams.show' )->only( 'show' );
        $this->middleware( 'can:teams.update' )->only( 'update' );
        $this->middleware( 'can:teams.destroy' )->only( 'destroy' );
        $this->middleware( 'can:teams.validateTeam' )->only( 'validateTeam' );
    }

    /**
     * Metodo para listar a todos los equipos
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $teams = Team::with('users')->with('countries')->get();
        return $this->showAll($teams);
    }

    /**
     * Metodo para agregar nuevos equipos
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function store()
    {
        $rules = [
            'name'           =>   ['required', 'string'],
            'description'    =>   ['required', 'string']
        ];

        $this->validate(request(), $rules);

        return $this->showOne(Team::create(request()->all()), 201);
    }

    /**
     * Metodo para mostrar un equipo
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function show(Team $team)
    {
        return $this->showOne($team);
    }

    /**
     * Metodo para actualizar equipos
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function update(Team $team)
    {
        $rules = [
            'name'           =>   ['string'],
            'description'    =>   ['string']
        ];

        $this->validate(request(), $rules);

        if (request('name')) {
            $team->name = request('name');
        }

        if (request('description')) {
            $team->description = request('description');
        }

        $tag->save();

        return $this->showOne($tag);
    }

    /**
     * Metodo para eliminar equipos
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function destroy(Team $team)
    {
        $team->users()->detach();
        $team->countries()->detach();
        $team->delete();
        return $this->showOne( $team );
    }

    /**
     * Metodo para validar team
        ROLES
        ** Superadministrators
        ** Administrators
     *
     * @return \Illuminate\Http\Response
     */
    public function validateTeam(Country $country)
    {
        if (!auth()->user()->hasRole( 'superadministrator' ) && !auth()->user()->hasRole( 'administrator' )) {
            if (!$this->validateTeamPermissions($country->id)) {
                return $this->errorResponse('Error, you do not have access to this resource', 403);
            }
        } 
        return $this->showMessage(true, 200);
    }
}
