<?php

namespace App\Http\Controllers\Team;

use App\Http\Controllers\ApiController;
use App\Http\Controllers\Controller;
use App\Team;
use App\User;

class TeamUserController extends ApiController
{

    public function __construct()
    {
        parent::__construct();
        $this->middleware( 'can:teams.users.store' )->only( 'store' );
        $this->middleware( 'can:teams.users.show' )->only( 'show' );
        $this->middleware( 'can:teams.users.destroy' )->only( 'destroy' );
    }

    /**
     * Metodo para agregar usuarios a un equipo
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function store(Team $team)
    {
        // if ($user->hasRole('administrator')) {
        //     $team->users()->syncWithoutDetaching( $user->id );
        //     return $this->showOne( $team );   
        // }
        // return $this->errorResponse('Error, Only administrator type users are allowed', 403);
        // {"users_ids":[12,212,212,232,23,2222]}
        $rules = [
            'users_ids.*' => ['numeric']
        ];

        $this->validate(request(), $rules);

        $team->users()->detach();

        foreach (request( 'users_ids' ) as $key => $user_id) {
            $team->users()->syncWithoutDetaching( $user_id );
        }

        $team = $team->load('users')->load('countries');

        return $this->showOne($team);
    }

    /**
     * Metodo para mostrar los usuarios de un equipo
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
     */
    public function show(Team $team)
    {
        return $this->showAll( $team->users()->get() );
    }

    /**
     * Metodo para eliminar un usuario de un equipo
        ROLES
        ** Superadministrators
     *
     * @return \Illuminate\Http\Response
    */
    public function destroy(Team $team, User $user)
    {
        $team->users()->detach($user->id);
        return $this->showOne($team);
    }
}
