<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class Wall extends Model
{
    const INDOOR = 'indoor';
	const OUTDOOR = 'outdoor';

	const VERTICAL = 'vertical';
	const HORIZONTAL = 'horizontal';
	const SQUARE = 'square';

	/**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'company_id',
        'country_id',
		'provider_wall_id',
		'ooh',
		'type',
		'country',
		'state',
		'town_hall_delegation',
		'suburb',
		'street',
		'location_number',
		'postal_code',
		'latitude',
		'longitude',
		'latitude_view',
		'longitude_view',
		'vertical_horizontal',
		'measured_in_meters',
		'average_monthly_impacts',
		'average_speed',
		'photographic_witness',
		'local_currency',
		'description',
		'purchase_remarks',
		'witness_time',
		'url_img',
		'business_type',
		'business_name',
		'minimum_days',
		'tags',
		'black_list',
		'circuit_id',
        'disabled',
        'material_art',
        'number_faces',
        'light',
        'type_installation',
        'sales_model',
        'production_cost',
        'installation_cost',
        'third_party_printing',
        'requires_art',
        'art_format',
        'quality_art',
        'art_printing_time',
        'art_installation_time',
        'additional_requirements',
        'availability_flag'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
    ];

    // Cast Data
    protected $casts = [
        'latitude'        =>  'double',
        'longitude'       =>  'double',
        'latitude_view'   =>  'double',
        'longitude_view'  =>  'double',
        'local_currency'  =>  'double',
        'light'           =>  'boolean',
        'third_party_printing'  =>  'boolean',
        'availability_flag'     =>  'boolean',
    ];

    /* Mutadores, cambiaran el valor antes de insertar valores */
    public function setProviderWallIdAttribute($provider_wall_id) {
        $this->attributes['provider_wall_id'] = strtolower($provider_wall_id);
    }

    public function setOohAttribute($ooh) {
        $this->attributes['ooh'] = mb_strtolower($ooh);
    }

    public function setTypeAttribute($type) {
        $this->attributes['type'] = mb_strtolower($type);
    }

    public function setMaterialArtAttribute($material_art) {
        $this->attributes['material_art'] = mb_strtolower($material_art);
    }

    public function setTypeInstallationAttribute($type_installation) {
        $this->attributes['type_installation'] = mb_strtolower($type_installation);
    }

    public function setSalesModelAttribute($sales_model) {
        $this->attributes['sales_model'] = mb_strtolower($sales_model);
    }

    public function setRequiresArtAttribute($requires_art) {
        $this->attributes['requires_art'] = mb_strtolower($requires_art);
    }

    public function setArtFormatAttribute($art_format) {
        $this->attributes['art_format'] = mb_strtolower($art_format);
    }

    public function setQualityArtAttribute($quality_art) {
        $this->attributes['quality_art'] = mb_strtolower($quality_art);
    }

    public function setAdditionalRequirementsAttribute($additional_requirements) {
        $this->attributes['additional_requirements'] = mb_strtolower($additional_requirements);
    }

    public function setCountryAttribute($country) {
        $this->attributes['country'] = mb_strtolower($country);
    }

    public function setStateAttribute($state) {
        $this->attributes['state'] = mb_strtolower($state);
    }

    public function setTownHallDelegationAttribute($town_hall_delegation) {
        $this->attributes['town_hall_delegation'] = mb_strtolower($town_hall_delegation);
    }

    public function setSuburdAttribute($suburb) {
        $this->attributes['suburb'] = mb_strtolower($suburb);
    }

    public function setStreetAttribute($street) {
        $this->attributes['street'] = mb_strtolower($street);
    }

    public function setLocationNumberAttribute($location_number) {
        $this->attributes['location_number'] = mb_strtolower($location_number);
    }

    public function setVerticalHorizontalAttribute($vertical_horizontal) {
        $this->attributes['vertical_horizontal'] = mb_strtolower($vertical_horizontal);
    }

    public function setWebcamAttribute($webcam) {
        $this->attributes['webcam'] = strtolower($webcam);
    }

    public function setPhotographicWitnessAttribute($photographic_witness) {
        $this->attributes['photographic_witness'] = strtolower($photographic_witness);
    }

    public function setDescriptionAttribute($description) {
        $this->attributes['description'] = mb_strtolower($description);
    }

    public function setPurchaseRemarksAttribute($purchase_remarks) {
        $this->attributes['purchase_remarks'] = mb_strtolower($purchase_remarks);
    }

    public function setWitnessTimeAttribute($witness_time) {
        $this->attributes['witness_time'] = mb_strtolower($witness_time);
    }

    public function setBusinessTypeAttribute($business_type) {
        $this->attributes['business_type'] = mb_strtolower($business_type);
    }

    public function setBusinessNameAttribute($business_name) {
        $this->attributes['business_name'] = mb_strtolower($business_name);
    }

    public function setDisplayNameAttribute($display_name) {
        $this->attributes['display_name'] = mb_strtolower($display_name);
    }

    public function setSupportsImageAttribute($supports_image) {
        $this->attributes['supports_image'] = strtolower($supports_image);
    }

    public function setSupportsVideoAttribute($supports_video) {
        $this->attributes['supports_video'] = strtolower($supports_video);
    }

    public function setSupportsImageGifAttribute($supports_image_gif) {
        $this->attributes['supports_image_gif'] = strtolower($supports_image_gif);
    }

    public function setProgramaticTraditionalAttribute($programatic_traditional) {
        $this->attributes['programatic_traditional'] = mb_strtolower($programatic_traditional);
    }

    public function setTagsAttribute($tags) {
        $this->attributes['tags'] = mb_strtolower($tags);
    }

    public function setBlackListAttribute($black_list) {
        $this->attributes['black_list'] = mb_strtolower($black_list);
    }

    public function setCircuitIdAttribute($circuit_id) {
        $this->attributes['circuit_id'] = strtolower($circuit_id);
    }

    public function setNameOfTheDataProviderAttribute($name_of_the_data_provider) {
        $this->attributes['name_of_the_data_provider'] = mb_strtolower($name_of_the_data_provider);
    }

    public function setProviderDataIdAttribute($provider_data_id) {
        $this->attributes['provider_data_id'] = strtolower($provider_data_id);
    }

    public function company() {
        return $this->belongsTo(Company::class);
    }

    public function country() {
        return $this->belongsTo(Country::class);
    }

    public function circuit() {
        return $this->belongsTo(Circuit::class);
    }

    public function campaigns() {
        return $this->belongsToMany(Campaign::class, 'campaign_walls')->withPivot('flag');
    }

    public function impacts() {
        return $this->hasMany(ImpactData::class);
    }

    public function images()
    {
        return $this->hasMany(GalleryWall::class);
    }

    public function availability()
    {
        return $this->hasMany(Availability::class);
    }
}
