<?php

use Illuminate\Http\Request;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

/* Api Home */
Route::get('/', function() {
	return '&copy; Prodooh - Todos los derechos reservador '.date('Y');
});

/* USERS */
Route::namespace('User')->group(function() {
	Route::prefix('users')->name('users.')->group(function() {
		Route::get('adminsales', 'UserController@usersAdminSales')->name('adminsales');
		Route::get('superadministrators', 'UserController@getAllSuperAdministrators')->name('superadministrators');
		Route::get('administrators', 'UserController@getAllAdministrators')->name('dministrators');
		Route::get('salesmanager', 'UserController@getAllSalesManager')->name('salesmanager');
		Route::get('provideradministrators', 'UserController@getAllProvidersAdministrators')->name('provideradministrator');
		Route::get('sellerscosts', 'UserController@getAllSellersCosts')->name('sellerscosts');
		Route::get('sellers', 'UserController@getAllSellers')->name('sellers');
		Route::get('customerscosts', 'UserController@getAllCustomersCosts')->name('customerscosts');
		Route::get('customers', 'UserController@getAllCustomers')->name('customers');
		Route::get('suspended', 'UserController@getAllUsersSuspended')->name('suspended');
		Route::get('me', 'UserController@me')->name('me');
		Route::get('campaigns/{user}', 'UserCampaignController@index')->name('campaigns.index');
		Route::get('seller/customers', 'UserController@usersSeller')->name('seller.customers');
		Route::get('logout', 'UserController@logout')->name('logout');
		Route::post('upload/image', 'UserController@uploadImage')->name('upload.image');
		Route::post('delete/image', 'UserController@deleteImage')->name('delete.image');
		Route::delete('{user}/delete/image', 'UserController@deleteUserImage')->name('user.delete.image');
		Route::post('search', 'UserController@search')->name('search');
		Route::get('authenticated', 'UserController@authenticated')->name('authenticated');
	});

	Route::apiResource('users', 'UserController');

});

/*TAGS*/
Route::namespace('Tag')->group(function() {
	Route::apiResource('tags', 'TagController');
});

/* WALLS */
Route::namespace('Wall')->group(function() {

	Route::prefix('walls')->name('walls.')->group(function() {
		Route::get('walls-directory', 'WallController@getAllWallsDirectory')->name('get.walls');
		Route::post('filtered', 'WallController@filteredWalls')->name('filtered.walls');
		Route::get('provider/{company}', 'WallController@getWallProvider')->name('provider');
		Route::post('image/upload/{company}', 'WallController@uploadImage')->name('image.upload');
		Route::post('image/delete', 'WallController@deleteImage')->name('image.delete');
		Route::delete('{wall}/image/delete', 'WallController@deleteWallImage')->name('wall.image.delete');
		Route::delete('image-gallery/{galleryWall}/delete', 'WallController@deleteWallImageGallery')->name('wall.image.delete');
		Route::post('search', 'WallController@search')->name('search');
		Route::post('search/provider-id', 'WallController@searchWallProviderId')->name('search.provider_id');
        Route::post('search/provider', 'WallController@searchWallsProviderId')->name('search.wall.provider.id');
		Route::post('business-name', 'WallController@getNumberwallsNameBusiness')->name('number.businessname');
	});

	Route::apiResource('walls', 'WallController');

});

/* GALLERY */
Route::namespace('GalleryWall')->group(function() {

	Route::prefix('gallery-walls')->name('gallery-walls.')->group(function() {
		Route::post('upload/{wall}', 'GalleryWallController@store')->name('image.walls.upload');
	});

});


/*COUNTRIES*/
Route::namespace('Country')->group(function() {

	Route::prefix('countries')->name('countries.')->group(function() {
		Route::post('states', 'CountryController@getStatesCountry')->name('states');
	});
	Route::apiResource('countries', 'CountryController')->except('destroy');

});

/*TEAMS*/
Route::namespace('Team')->group(function() {

	Route::prefix('teams')->name('teams.')->group(function() {
		Route::post('{team}/users', 'TeamUserController@store')->name('users.store');
		Route::get('{team}/users', 'TeamUserController@show')->name('users.show');
		Route::delete('{team}/users/{user}', 'TeamUserController@destroy')->name('users.destroy');

		Route::post('{team}/countries', 'TeamCountryController@store')->name('countries.store');
		Route::get('{team}/countries', 'TeamCountryController@show')->name('countries.show');
		Route::delete('{team}/countries/{country}', 'TeamCountryController@destroy')->name('countries.destroy');
		Route::get( 'validate/{country}', 'TeamController@validateTeam' )->name('validate.team');
	});

	Route::apiResource('teams', 'TeamController');

});

/* COMPANIES */
Route::namespace('Company')->group(function() {

	// Route::apiResource('users/companies', 'CompanyUserController')->only('index');

	Route::prefix('companies')->name('companies.')->group(function() {
		Route::get('administrator', 'CompanyController@administratorCompanies')->name('administrator');
		Route::get('provider', 'CompanyController@providerCompanies')->name('provider');
		Route::get('reseller', 'CompanyController@resellerCompanies')->name('reseller');
		Route::get('client', 'CompanyController@clientCompanies')->name('client');

		Route::post('upload/image', 'CompanyController@uploadImage')->name('upload.image');
		Route::post('delete/image', 'CompanyController@deleteImage')->name('delete.image');
		Route::delete('{company}/delete/image', 'CompanyController@deleteCompanyImage')->name('company.delete.image');

		Route::post('{company}/multiplier/provider', 'CompanyController@setMultiplierProvider')->name('multiplier.provider.store');
		Route::get('{company}/multiplier/provider', 'CompanyController@getMultiplierProvider')->name('multiplier.provider.get');

		Route::post('{company}/multiplier/reseller', 'CompanyController@setMultiplierReseller')->name('multiplier.reseller.store');
		Route::get('{company}/multiplier/reseller', 'CompanyController@getMultiplierReseller')->name('multiplier.reseller.get');

		Route::get('campaigns/{campaign}/provider/multiplier', 'CompanyController@getMultiplierProvidersCampaign')->name('campaigns.provider.multiplier');

		Route::post('search', 'CompanyController@search')->name('search');

        Route::get('{company}/countries/percentage', 'CompanyController@showCompanyPercentage')->name('countries.percentage');
        Route::get('{company}/suppliers', 'CompanyController@showCompanySuppliers')->name('countries.suppliers');
	});

	Route::apiResource('companies', 'CompanyController')->except('destroy');

});

/* CIRCUITS */
Route::namespace('Circuit')->group(function() {

	Route::prefix('circuits')->name('circuits.')->group(function() {
		Route::get('{circuit}/walls/number', 'CircuitWallController@getNumberWallsCircuit')->name('walls.number');
		Route::get('{circuit}/walls', 'CircuitWallController@index')->name('walls.index');
	});

	Route::apiResource('circuits', 'CircuitController')->except('destroy');

});

/* CAMPAIGNS */
Route::namespace('Campaign')->group(function() {
	Route::prefix('campaigns')->name('campaigns.')->group(function() {
		Route::get('me', 'CampaignController@myCampaigns')->name('me');
		Route::get('customer', 'CampaignController@customerCampaigns')->name('customer');
		Route::get('adminsales', 'CampaignController@campaingsAdminSales')->name('adminsales');
		Route::get('{campaign}/duplicate', 'CampaignController@duplicate')->name('duplicate');
		Route::get('{campaign}/disable', 'CampaignController@disableCampaign')->name('disable');
		Route::get('{campaign}/activate', 'CampaignController@activateCampaign')->name('activate');
		Route::post('{campaign}/date-impacts', 'CampaignController@addDateImpactsCampaign')->name('date-impacts');

		Route::get('salesmanager/editables', 'CampaignController@getAllCampaignsEditablesAdminSales')->name('salesmanager.editables');
		Route::get('editables', 'CampaignController@getAllCampaignsEditables')->name('editables');
		Route::get('me/editables', 'CampaignController@getAllMyCampaignsEditables')->name('me.editables');

		Route::get('{campaign}/walls', 'CampaignWallController@index')->name('walls.index');
		Route::post('{campaign}/walls', 'CampaignWallController@store')->name('walls.store');
		Route::delete('{campaign}/walls/{wall}', 'CampaignWallController@destroy')->name('walls.delete');
		Route::delete('{campaign}/circuit/{circuit}', 'CampaignWallController@destroyCircuit')->name('circuit.delete');

		Route::get('{campaign}/polygons', 'CampaignPolygonController@index')->name('polygons.index');
		Route::post('{campaign}/polygons', 'CampaignPolygonController@store')->name('polygons.store');
		Route::post('{campaign}/polygons/{polygon}', 'CampaignPolygonController@destroy')->name('polygons.destroy');

		Route::get('{campaign}/points', 'CampaignPointOfInterestController@index')->name('points.index');
		Route::post('{campaign}/points', 'CampaignPointOfInterestController@store')->name('points.store');
		Route::post('{campaign}/points/{PointOfInterest}', 'CampaignPointOfInterestController@destroy')->name('points.destroy');

		Route::get('{campaign}/pdf/budget', 'CampaignController@getPDFBudget')->name('pdf/budget');

		Route::get('{campaign}/walls/export', 'CampaignWallController@export');

		Route::post('search', 'CampaignController@search')->name('search');
		Route::post('search/me', 'CampaignController@searchMe')->name('search.me');
		Route::get('wall/{wall}/year/{year}/week/{week}', 'CampaignWallController@getCampaignsWallAvailability')->name('campaigns.wall.availability');

		Route::get('{campaign}/mapping-files', 'CampaignMappingFileController@index')->name('mapping-files.index');
		Route::post('{campaign}/mapping-files', 'CampaignMappingFileController@store')->name('mapping-files.store');

        Route::get('{campaign}/providers', 'CampaignPucharseOrderController@index')->name('pucharse-orders.index');
        Route::get('{campaign}/provider/{company}', 'CampaignPucharseOrderController@exportPDF')->name('pucharse-orders.exportPDF');

        Route::post('witnesses/upload/image/{campaign}', 'CampaignPhotographicWitnessesController@store')->name('witnesses.store');
        Route::get('{campaign}/witnesses', 'CampaignPhotographicWitnessesController@index')->name('witnesses.index');
        Route::delete('witnesses/{image}', 'CampaignPhotographicWitnessesController@destroy')->name('witnesses.destroy');
        Route::put('witnesses/{witness}', 'CampaignPhotographicWitnessesController@update')->name('witnesses.update');
        Route::get('witnesses', 'CampaignPhotographicWitnessesController@indexWitnesses')->name('witnesses.indexWitnesses');
        Route::post('witnesses/search', 'CampaignPhotographicWitnessesController@searchWitnesses')->name('witnesses.searchWitnesses');
        Route::get('{campaign}/witnesses/download/zip', 'CampaignPhotographicWitnessesController@downloadZip')->name('witnesses.download.zip');
	});

	// Route::apiResource('pointsofinterest', 'CampaignPointOfInterestController')->only('store', 'destroy', 'index');
	Route::apiResource('campaigns', 'CampaignController');

});


/*OAUTH*/
Route::prefix('oauth')->name('oauth.')->group(function() {

	Route::post('token', '\Laravel\Passport\Http\Controllers\AccessTokenController@issueToken');

	Route::get('token/validate', function () {
	    return ['message' => 'ok', 'code' => 200];
	})->middleware('auth:api');

});

/* BUDGET */
Route::namespace('Budget')->group(function() {
	Route::prefix('budgets')->name('budgets.')->group(function() {
		Route::post('{campaign}', 'BudgetController@store')->name('store');
		Route::get('{campaign}', 'BudgetController@show')->name('show');
	});
});

/* PARTICULAR POINTS OF INTEREST */
Route::namespace('ParticularPointOfInterest')->group(function() {
	Route::prefix('particular-points-interest')->name('particular-points-interest.')->group(function() {
		Route::post('upload', 'ParticularPointOfInterestController@uploadFile')->name('upload.file');
		Route::post('delete/file', 'ParticularPointOfInterestController@deleteFile')->name('delete.file');
		Route::post('show', 'ParticularPointOfInterestController@show')->name('show');
		Route::post('points', 'ParticularPointOfInterestController@getPoints')->name('points');
		Route::delete('delete/{point}', 'ParticularPointOfInterestController@deletePoint')->name('delete');
		Route::post('point', 'ParticularPointOfInterestController@storePoint')->name('store');
		Route::post('point/{point}', 'ParticularPointOfInterestController@updatePoint')->name('store');
		Route::post('points/delete', 'ParticularPointOfInterestController@deletePoints')->name('points.delete');
	});
	Route::apiResource('particular-points-interest', 'ParticularPointOfInterestController')->except('show', 'delete');
});

/* KMLs KMZs */
Route::namespace('MappingFile')->group(function() {
	Route::prefix('mapping-file')->name('mapping-file.')->group(function() {
		Route::post('upload', 'MappingFileController@uploadFile')->name('upload.file');
		Route::post('delete/file', 'MappingFileController@deleteFile')->name('delete.file');
	});
	Route::apiResource('mapping-file', 'MappingFileController')->except('show');
});

/* Impacts Walls */
Route::namespace('Impact')->group(function() {
	Route::prefix('impacts')->name('impacts.')->group(function() {
		Route::post('upload', 'ImpactController@uploadFile')->name('upload.file');
		Route::post('delete/file', 'ImpactController@deleteFile')->name('delete.file');
		Route::get('{impact}/list', 'ImpactController@getImpacts')->name('list');
		Route::get('wall/{wall}', 'ImpactController@getImpactsWall')->name('wall');
		Route::get('wall/{wall}/list', 'ImpactController@getImpactsListWall')->name('wall');
		Route::get('{impact}/wall/{wall}', 'ImpactController@getImpactsWallDataRange')->name('wall');
		Route::post('filtered', 'ImpactController@filteredImpacts')->name('filtered');
		Route::post('impact', 'ImpactController@storeImpact')->name('impact');
		Route::delete('impact/{impact}', 'ImpactController@destroyImpact')->name('delete.impact');
		Route::post('data/range', 'ImpactController@getImpactsDataRange')->name('data.range');
	});
	Route::apiResource('impacts', 'ImpactController')->except('show');
});

/*PUBLIC*/
Route::namespace('AccessPublic')->prefix('public')->name('public.')->group(function() {
	Route::get('campaign/{campaign}', 'CampaingPublicController@show')->name('show.campaigns');
	Route::get('campaign/{campaign}/walls/impacts', 'CampaignWallImpactController@index')->name('campaign.walls.impacts.index');
	Route::post('campaign/{campaign}/walls/impacts', 'CampaignWallImpactController@show')->name('campaign.walls.impacts.show');
	Route::post('walls/{wall}/impacts', 'CampaignWallImpactController@showWall')->name('campaign.walls.impacts.showWall');
    Route::get('campaign/{campaign}/witnesses', 'CampaignWitnessController@index')->name('campaign.witnesses.index');
	Route::post('campaign/{campaign}/export/audience', 'CampaignWallImpactController@exportAudience');
});

/* Impacts Walls */
Route::namespace('File')->group(function() {
	Route::prefix('file-manager')->name('file-manager.')->group(function() {
		Route::post('upload', 'FileController@uploadFile')->name('upload.file');
		Route::post('delete', 'FileController@deleteFile')->name('delete.file');
	});
	Route::apiResource('file-manager', 'FileController')->except('show');
});

/* AVAILABILITY */
Route::namespace('AvailabilityWall')->group(function() {
	Route::prefix('availability')->name('availability.')->group(function() {
		Route::get('wall/{wall}/year/{year}', 'AvailabilityWallController@availabilityWallYear')->name('availability.wall.year');
		Route::get('wall/{wall}/campaign/{campaign}', 'AvailabilityWallCampaignController@show')->name('show.availability.wall.campaign');
		Route::post('wall/{wall}/campaign/{campaign}', 'AvailabilityWallCampaignController@update')->name('update.availability.wall.campaign');
		Route::get('campaign/{campaign}', 'AvailabilityWallCampaignController@indexCampaignWalls')->name('availability.campaign.walls');
		Route::post('walls/year/{year}', 'AvailabilityWallController@index')->name('index.availability.walls');
		Route::post('provider', 'AvailabilityWallController@storeDatesProvider')->name('store.dates.provider');
		Route::delete('provider/wall/{wall}/year/{year}', 'AvailabilityWallController@destroy')->name('delete.dates.provider');
		Route::delete('wall/{wall}/week/{week}', 'AvailabilityWallController@updateWeekDateWall')->name('delete.date.week.wall');
	});
	Route::apiResource('availability', 'AvailabilityWallController')->except('index');
});
